% Frame MATLAB Code with Member Loads
% Units: Kilonewtons (kN) and Millimeters (mm)

clc     %Clear the window
clear   %Clear the memory

% This general format works well for most engineering problems
format short g

% Define the number of element dofs (always 6 for the frame element)
NEdof=6;

% Define the number of structural dofs
NSdof=6;

% Initialize {Pf} and [S]
P=zeros(NSdof,1);
Pf=zeros(NSdof,1);
S=zeros(NSdof,NSdof);

E=30;

%Define nonzero terms in P

P(1)=36;
P(5)=-18;

% Define the code numbers
CodeNum=[
7 8 9  1  2  3
1 2 3  4  5  6
4 5 6 10 11 12] % Here we write out each row explicitly

% Define geometry and loading for each member, create the member stiffness and fixed-end-force vectors
% and then assemble {Pf} and [S]. Note that no units are shown, you just need to
% be consistent.

MemNum=1;
Qf1=zeros(NEdof,1);
A=3.0e4;
I=1.0e8;
LX=0;       % sign (+/-) important
LY=5e3;     % sign (+/-) important

Qf1

[K1,Ff1,T1]=Create_TKF(E,I,A,LX,LY,Qf1)
[S,Pf]=Assemble_S_Pf(S,K1,Pf,Ff1,MemNum,NEdof,NSdof,CodeNum);


MemNum=2;
Qf2=zeros(NEdof,1);
A=3.0e4;
I=1.0e8;
LX=4e3;    % sign (+/-) important
LY=3e3;    % sign (+/-) important

L=sqrt(LX^2+LY^2);

               % Fixed End Forces/Moments 
w=12/1000;     % Note: (+) Distributed FORCE assumed down

FAb=0;
FSb=w*L/2;
FMb=w*L^2/12;
FAe=0;
FSe=w*L/2;
FMe=-w*L^2/12;

Qf2=[FAb;FSb;FMb;FAe;FSe;FMe];

Qf2

[K2,Ff2,T2]=Create_TKF(E,I,A,LX,LY,Qf2)
[S,Pf]=Assemble_S_Pf(S,K2,Pf,Ff2,MemNum,NEdof,NSdof,CodeNum);


MemNum=3;
Qf3=zeros(NEdof,1);
A=3.0e4;
I=1.0e8;
LX=5e3;       % sign (+/-) important
LY=0;         % sign (+/-) important

a=3e3;                      % Fixed End Forces/Moments
b=2e3;                     
                            
M=24*1000;                  % Note: (+) Concentrated MOMENT assumed CW
FSb=-6*M*(a*b)/(L^3);          
FMb=M*b*(b-2*a)/(L^2);      % (+) reactions: force UP, (+) moment CCW
FSe=6*M*(a*b)/(L^3);
FMe=M*a*(a-2*b)/(L^2);

Qf3=[FAb;FSb;FMb;FAe;FSe;FMe];

Qf3

[K3,Ff3,T3]=Create_TKF(E,I,A,LX,LY,Qf3)
[S,Pf]=Assemble_S_Pf(S,K3,Pf,Ff3,MemNum,NEdof,NSdof,CodeNum);


%***************** SOLVE *****************

% Solve for displacements (note the use of the backslash operator instead
% of the inv command. We could have used d=inv(S)*(P-Pf), or even
% d=S^-1*(P-Pf), but the backslash approach is much more efficient.)

P
Pf
S

d=S\(P-Pf)


%************** POST-PROCESS *************

% Use compatibility to create the {v} vectors for each element
v1=[0; 0; 0; d(1); d(2); d(3)];
v2=[d(1); d(2); d(3); d(4); d(5); d(6)];
v3=[d(4); d(5); d(6); 0; 0; 0];

% Calculate the member end forces (global)
F1=Ff1+K1*v1
F2=Ff2+K2*v2
F3=Ff3+K3*v3

% Calculate the member end forces (local)
Q1=T1*F1
Q2=T2*F2
Q3=T3*F3

% Calculate the support reactions
R7=F1(1)
R8=F1(2)
R9=F1(3)
R10=F3(4)
R11=F3(5)
R12=F3(6)    

